@@ -294,7 +294,7 @@ Ext.define('MP.grid.plugin.FilterBar', {
         if (grid.rendered) {
             me.renderFilterBar(grid);
         } else {
-            grid.on('afterrender', me.renderFilterBar, me, { single: true });
+            grid.on('viewready', me.renderFilterBar, me, { single: true });
         }
     },
 
@@ -655,23 +655,6 @@ Ext.define('MP.grid.plugin.FilterBar', {
             me.containers.add(column.dataIndex, container);
             container.render(Ext.get(column.id));
         }, me);
-        var excludedCols = [];
-        if (me.actionColumn) excludedCols.push(me.actionColumn.id);
-        if (me.extraColumn) excludedCols.push(me.extraColumn.id);
-        Ext.each(me.grid.headerCt.getGridColumns(), function(column) {
-            if (!Ext.Array.contains(excludedCols, column.id)) {
-                column.setPadding = Ext.Function.createInterceptor(column.setPadding, function(h) {
-                    //jsl:unused h
-                    if (column.hasCls(Ext.baseCSSPrefix + 'column-header-checkbox')) { //checkbox column
-                        this.titleEl.setStyle({
-                            paddingTop: '4px'
-                        });
-                    }
-                    return false;
-                });
-            }
-        });
-
 
         me.setVisible(me.visible);
 
@@ -972,3 +955,21 @@ Ext.define('MP.grid.plugin.FilterBar', {
         me.visible = visible;
     }
 });
+
+/* This is needed on ExtJS 4.2.1 to avoid title vertical recentering while
+ * filters are enabled
+ */
+Ext.define('MP.override.grid.ColumnComponentLayout', {
+    override: 'Ext.grid.ColumnComponentLayout',
+
+    /**
+     * Don't recalculate the inner height when a filter config
+     * is applied to the column
+     */
+    publishInnerHeight: function(ownerContext, outerHeight) {
+        if (this.owner.filter) {
+            return;
+        }
+        this.callParent(arguments);
+    }
+});
